==> openjfx_11.0.7+0.orig.tar.xz: openjdk-jfx-11.0.7-0/modules/javafx.web/src/main/native/Source/JavaScriptCore/bytecode/OperandsInlines.h <==
/*
 * Copyright (C) 2013, 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "Operands.h"
#include <wtf/CommaPrinter.h>

namespace JSC {

template<typename T>
void Operands<T>::dumpInContext(PrintStream& out, DumpContext* context) const
{
    CommaPrinter comma(" ");
    for (size_t argumentIndex = numberOfArguments(); argumentIndex--;) {
        if (!argument(argumentIndex))
            continue;
        out.print(comma, "arg", argumentIndex, ":", inContext(argument(argumentIndex), context));
    }
    for (size_t localIndex = 0; localIndex < numberOfLocals(); ++localIndex) {
        if (!local(localIndex))
            continue;
        out.print(comma, "loc", localIndex, ":", inContext(local(localIndex), context));
    }
}

template<typename T>
void Operands<T>::dump(PrintStream& out) const
{
    CommaPrinter comma(" ");
    for (size_t argumentIndex = numberOfArguments(); argumentIndex--;) {
        if (!argument(argumentIndex))
            continue;
        out.print(comma, "arg", argumentIndex, ":", argument(argumentIndex));
    }
    for (size_t localIndex = 0; localIndex < numberOfLocals(); ++localIndex) {
        if (!local(localIndex))
            continue;
        out.print(comma, "loc", localIndex, ":", local(localIndex));
    }
}

} // namespace JSC

==> openjfx_11.0.11+1.orig.tar.xz: openjdk-jfx-11.0.11-1/modules/javafx.web/src/main/native/Source/JavaScriptCore/bytecode/OperandsInlines.h <==
/*
 * Copyright (C) 2013, 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "Operands.h"
#include <wtf/CommaPrinter.h>

namespace JSC {

inline void Operand::dump(PrintStream& out) const
{
    if (isTmp())
        out.print("tmp", value());
    else
        out.print(virtualRegister());
}

template<typename T>
void Operands<T>::dumpInContext(PrintStream& out, DumpContext* context) const
{
    CommaPrinter comma(" ");
    for (size_t argumentIndex = numberOfArguments(); argumentIndex--;) {
        if (!argument(argumentIndex))
            continue;
        out.print(comma, "arg", argumentIndex, ":", inContext(argument(argumentIndex), context));
    }
    for (size_t localIndex = 0; localIndex < numberOfLocals(); ++localIndex) {
        if (!local(localIndex))
            continue;
        out.print(comma, "loc", localIndex, ":", inContext(local(localIndex), context));
    }
    for (size_t tmpIndex = 0; tmpIndex < numberOfTmps(); ++tmpIndex) {
        if (!tmp(tmpIndex))
            continue;
        out.print(comma, "tmp", tmpIndex, ":", inContext(tmp(tmpIndex), context));
    }
}

template<typename T>
void Operands<T>::dump(PrintStream& out) const
{
    CommaPrinter comma(" ");
    for (size_t argumentIndex = numberOfArguments(); argumentIndex--;) {
        if (!argument(argumentIndex))
            continue;
        out.print(comma, "arg", argumentIndex, ":", argument(argumentIndex));
    }
    for (size_t localIndex = 0; localIndex < numberOfLocals(); ++localIndex) {
        if (!local(localIndex))
            continue;
        out.print(comma, "loc", localIndex, ":", local(localIndex));
    }
    for (size_t tmpIndex = 0; tmpIndex < numberOfTmps(); ++tmpIndex) {
        if (!tmp(tmpIndex))
            continue;
        out.print(comma, "tmp", tmpIndex, ":", tmp(tmpIndex));
    }
}

} // namespace JSC
